NativeToastProPlatform class abstract

Platform interface for NativeToastPro

This abstract class defines the contract that all platform implementations must follow to provide native toast functionality.

Inheritance
  • Object
  • PlatformInterface
  • NativeToastProPlatform
Implementers

Constructors

NativeToastProPlatform()
Constructs a NativeToastProPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
Gets the platform version for compatibility checking
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showToast(String message) Future<void>
Shows a native toast message on the current platform
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NativeToastProPlatform
The default instance of NativeToastProPlatform to use.
getter/setter pair